@@ -297,7 +297,7 @@ TqInt CqSurfacePatchBicubic::PreSubdivide( std::vector<boost::shared_ptr<CqSurfa
 /** Determine whether or not the patch is diceable
  */
 
-bool	CqSurfacePatchBicubic::Diceable()
+bool	CqSurfacePatchBicubic::Diceable(const CqMatrix& matCtoR)
 {
 	assert( NULL != P() );
 	// If the cull check showed that the primitive cannot be diced due to crossing the e and hither planes,
@@ -306,23 +306,21 @@ bool	CqSurfacePatchBicubic::Diceable()
 		return ( false );
 
 	// Otherwise we should continue to try to find the most advantageous split direction, OR the dice size.
-	CqMatrix matCtoR;
-	QGetRenderContext() ->matSpaceToSpace( "camera", "raster", NULL, NULL, QGetRenderContext()->Time(), matCtoR );
 
 	// Convert the control hull to raster space.
-	CqVector2D	avecHull[ 16 ];
+	CqVector3D	avecHull[ 16 ];
 
 	for (TqInt i = 0; i < 16; i++ )
-		avecHull[i] = vectorCast<CqVector2D>(matCtoR * P()->pValue(i)[0]);
+		avecHull[i] = vectorCast<CqVector3D>(matCtoR * P()->pValue(i)[0]);
 
 	TqFloat uLen = 0;
 	TqFloat vLen = 0;
 
 	for (TqInt u = 0; u < 16; u += 4 )
 	{
-		CqVector2D	Vec1 = avecHull[ u + 1 ] - avecHull[ u ];
-		CqVector2D	Vec2 = avecHull[ u + 2 ] - avecHull[ u + 1 ];
-		CqVector2D	Vec3 = avecHull[ u + 3 ] - avecHull[ u + 2 ];
+		CqVector3D	Vec1 = avecHull[ u + 1 ] - avecHull[ u ];
+		CqVector3D	Vec2 = avecHull[ u + 2 ] - avecHull[ u + 1 ];
+		CqVector3D	Vec3 = avecHull[ u + 3 ] - avecHull[ u + 2 ];
 		if ( Vec1.Magnitude2() > uLen )
 			uLen = Vec1.Magnitude2();
 		if ( Vec2.Magnitude2() > uLen )
@@ -332,9 +330,9 @@ bool	CqSurfacePatchBicubic::Diceable()
 	}
 	for (TqInt v = 0; v < 4; v++ )
 	{
-		CqVector2D	Vec1 = avecHull[ v + 4 ] - avecHull[ v ];
-		CqVector2D	Vec2 = avecHull[ v + 8 ] - avecHull[ v + 4 ];
-		CqVector2D	Vec3 = avecHull[ v + 12 ] - avecHull[ v + 8 ];
+		CqVector3D	Vec1 = avecHull[ v + 4 ] - avecHull[ v ];
+		CqVector3D	Vec2 = avecHull[ v + 8 ] - avecHull[ v + 4 ];
+		CqVector3D	Vec3 = avecHull[ v + 12 ] - avecHull[ v + 8 ];
 		if ( Vec1.Magnitude2() > vLen )
 			vLen = Vec1.Magnitude2();
 		if ( Vec2.Magnitude2() > vLen )
@@ -670,7 +668,7 @@ TqInt CqSurfacePatchBilinear::PreSubdivide( std::vector<boost::shared_ptr<CqSurf
 /** Determine whether or not the patch is diceable
  */
 
-bool	CqSurfacePatchBilinear::Diceable()
+bool	CqSurfacePatchBilinear::Diceable(const CqMatrix& matCtoR)
 {
 	assert( NULL != P() );
 
@@ -680,21 +678,19 @@ bool	CqSurfacePatchBilinear::Diceable()
 		return ( false );
 
 	// Otherwise we should continue to try to find the most advantageous split direction, OR the dice size.
-	CqMatrix matCtoR;
-	QGetRenderContext() ->matSpaceToSpace( "camera", "raster", NULL, NULL, QGetRenderContext()->Time(), matCtoR );
 
 	// Convert the control hull to raster space.
-	CqVector2D	avecHull[ 4 ];
+	CqVector3D	avecHull[ 4 ];
 	TqInt i;
 
 	for ( i = 0; i < 4; i++ )
-		avecHull[i] = vectorCast<CqVector2D>(matCtoR * P()->pValue(i)[0]);
+		avecHull[i] = vectorCast<CqVector3D>(matCtoR * P()->pValue(i)[0]);
 
 	TqFloat uLen = 0;
 	TqFloat vLen = 0;
 
-	CqVector2D	Vec1 = avecHull[ 1 ] - avecHull[ 0 ];
-	CqVector2D	Vec2 = avecHull[ 3 ] - avecHull[ 2 ];
+	CqVector3D	Vec1 = avecHull[ 1 ] - avecHull[ 0 ];
+	CqVector3D	Vec2 = avecHull[ 3 ] - avecHull[ 2 ];
 	uLen = ( Vec1.Magnitude2() > Vec2.Magnitude2() ) ? Vec1.Magnitude2() : Vec2.Magnitude2();
 
 	Vec1 = avecHull[ 2 ] - avecHull[ 0 ];
@@ -707,7 +703,6 @@ bool	CqSurfacePatchBilinear::Diceable()
 
 	m_SplitDir = ( uLen > vLen ) ? SplitDir_U : SplitDir_V;
 
-	// TODO: Should ensure powers of half to prevent cracking.
 	uLen = max<TqInt>(lround(uLen), 1);
 	vLen = max<TqInt>(lround(vLen), 1);
 
@@ -863,42 +858,85 @@ CqSurface* CqSurfacePatchMeshBicubic::Clone() const
 	clone->m_uPeriodic = m_uPeriodic;
 	clone->m_vPeriodic = m_vPeriodic;
 
+	clone->m_patches.insert(clone->m_patches.begin(), m_patches.begin(),
+							m_patches.end());
+
 	return ( clone );
 }
 
 
-
 //---------------------------------------------------------------------
 /** Get the boundary extents in camera space of the surface patch mesh
  */
 
 void CqSurfacePatchMeshBicubic::Bound(CqBound* bound) const
 {
-	assert( NULL != P() );
+	// The patch mesh must first have been split into its child patches,
+	//  which are assumed to have been transformed into the Bezier basis
+	//  and are also in camera-space coordinates.
+	assert(m_patches.size() > 0);
 
-	// Get the boundary in camera space.
-	CqVector3D	vecA( FLT_MAX, FLT_MAX, FLT_MAX );
-	CqVector3D	vecB( -FLT_MAX, -FLT_MAX, -FLT_MAX );
-	TqUint i;
-	for ( i = 0; i < P() ->Size(); i++ )
+	// Get the bound in camera space, by encapsulating the bounds of the
+	//  child patches.
+	CqBound patchBound;
+	std::vector<boost::shared_ptr<CqSurfacePatchBicubic> >::const_iterator
+		iPatch, end;
+	iPatch = m_patches.begin();
+	end = m_patches.end();
+	(*(iPatch++))->Bound(bound);
+	for (; iPatch != end; iPatch++)
 	{
-		CqVector3D	vecV = vectorCast<CqVector3D>(P()->pValue( i )[0]);
-		if ( vecV.x() < vecA.x() )
-			vecA.x( vecV.x() );
-		if ( vecV.y() < vecA.y() )
-			vecA.y( vecV.y() );
-		if ( vecV.x() > vecB.x() )
-			vecB.x( vecV.x() );
-		if ( vecV.y() > vecB.y() )
-			vecB.y( vecV.y() );
-		if ( vecV.z() < vecA.z() )
-			vecA.z( vecV.z() );
-		if ( vecV.z() > vecB.z() )
-			vecB.z( vecV.z() );
+		(*iPatch)->Bound(&patchBound);
+		bound->Encapsulate(&patchBound);
 	}
-	bound->vecMin() = vecA;
-	bound->vecMax() = vecB;
-	AdjustBoundForTransformationMotion( bound );
+}
+
+
+//---------------------------------------------------------------------
+/** Transforms the surface by the specified matrix.
+ */
+void CqSurfacePatchMeshBicubic::Transform(
+	const CqMatrix& matTx,
+	const CqMatrix& matITTx,
+	const CqMatrix& matRTx,
+	TqInt iTime)
+{
+	// before we transform the patch mesh, we must first have called
+	//  ConvertToBezierBasis(), which in turn calls SplitInternally().
+	//  SplitInternally() will have created a cache of child bicubic patch
+	//  objects.  in this function, we presume that we are operating on the
+	//  child patches, and not on the original patch mesh.
+	assert(m_patches.size() != 0);
+
+	// transform each of the child patches
+	std::vector<boost::shared_ptr<CqSurfacePatchBicubic> >::iterator
+		iPatch, end;
+	end = m_patches.end();
+	for (iPatch = m_patches.begin(); iPatch != end; iPatch++) {
+		(*iPatch)->Transform(matTx, matITTx, matRTx, iTime);
+	}
+}
+
+
+//---------------------------------------------------------------------
+/** Convert the patch mesh to use a Bezier basis matrix.
+ */
+
+void CqSurfacePatchMeshBicubic::ConvertToBezierBasis()
+{
+	// split the patch mesh internally, so that it becomes a bag of
+	//  individual bicubic patches
+	SplitInternally();
+
+	CqMatrix matuBasis, matvBasis;
+	matuBasis = pAttributes()->GetMatrixAttribute("System", "Basis")[0];
+	matvBasis = pAttributes()->GetMatrixAttribute("System", "Basis")[1];
+
+	std::vector<boost::shared_ptr<CqSurfacePatchBicubic> >::iterator
+		iPatch, end;
+	end = m_patches.end();
+	for (iPatch = m_patches.begin(); iPatch != end; iPatch++)
+		(*iPatch)->ConvertToBezierBasis(matuBasis, matvBasis);
 }
 
 
@@ -906,12 +944,31 @@ void CqSurfacePatchMeshBicubic::Bound(CqBound* bound) const
 /** Split the patch mesh into individual patches and post them.
  */
 
+TqInt CqSurfacePatchMeshBicubic::Split(
+	std::vector<boost::shared_ptr<CqSurface> >& aSplits)
+{
+	// we should already have called ConvertToBezierBasis(), which in turn
+	//  calls SplitInternally().  SplitInternally() created an internal cache
+	//  of bicubic mesh child objects, which we can now directly append to
+	//  the vector of splits.
+	assert(m_patches.size() != 0);
+
+	aSplits.insert(aSplits.end(), m_patches.begin(), m_patches.end());
+	return m_patches.size();
+}
+
+
+//---------------------------------------------------------------------
+/** Internally split the patch mesh into individual child bicubic patches
+ *  and cache them.
+ */
+
 #define	PatchCoord(v,u)	((((v)%m_nv)*m_nu)+((u)%m_nu))
 #define	PatchCorner(v,u)	((((v)%nvaryingv)*nvaryingu)+((u)%nvaryingu));
 
-TqInt CqSurfacePatchMeshBicubic::Split( std::vector<boost::shared_ptr<CqSurface> >& aSplits )
+void CqSurfacePatchMeshBicubic::SplitInternally()
 {
-	TqInt cSplits = 0;
+	assert(m_patches.size() == 0);  // do not try to split twice!
 
 	CqVector4D vecPoint;
 	TqInt iP = 0;
@@ -1050,11 +1107,9 @@ TqInt CqSurfacePatchMeshBicubic::Split( std::vector<boost::shared_ptr<CqSurface>
 				pSurface->t() ->pValue( 3 ) [ 0 ] = BilinearEvaluate( st1.y(), st2.y(), st3.y(), st4.y(), u1, v1 );
 			}
 
-			aSplits.push_back( pSurface );
-			cSplits++;
+			m_patches.push_back( pSurface );
 		}
 	}
-	return ( cSplits );
 }
 
 
