@@ -174,8 +174,8 @@ class AQSIS_SHADERVM_SHARE CqShaderVM : public CqShaderStack, public IqShader, p
 		{
 			return ( m_Uses );
 		}
-		virtual IqShaderData* CreateVariable( EqVariableType Type, EqVariableClass Class, const CqString& name, bool fArgument = false, bool fOutput = false  );
-		virtual IqShaderData* CreateVariableArray( EqVariableType Type, EqVariableClass Class, const CqString& name, TqInt Count, bool fParameter = false, bool fOutput = false  );
+		virtual IqShaderData* CreateVariable( EqVariableType Type, EqVariableClass Class, const CqString& name, IqShaderData::EqStorage storage );
+		virtual IqShaderData* CreateVariableArray( EqVariableType Type, EqVariableClass Class, const CqString& name, TqInt Count, IqShaderData::EqStorage storage );
 		virtual	IqShaderData* CreateTemporaryStorage( EqVariableType type, EqVariableClass _class );
 		virtual void DeleteTemporaryStorage( IqShaderData* pData );
 		virtual void DefaultSurface();
@@ -192,15 +192,6 @@ class AQSIS_SHADERVM_SHARE CqShaderVM : public CqShaderStack, public IqShader, p
 		static	void ShutdownShaderEngine();
 
 
-		/** \brief Load a compiled shader program from the given stream
-		 *
-		 * \throw XqBadShader If the program was compiled with a different
-		 *   version of aqsis, or is invalid in any other way.
-		 */
-		void	LoadProgram( std::istream* pFile );
-		void	Execute( IqShaderExecEnv* pEnv );
-		void	ExecuteInit();
-
 		virtual const std::vector<IqShaderData*>& GetArguments() const;
 		void SetType(EqShaderType type);
 
@@ -215,6 +206,19 @@ class AQSIS_SHADERVM_SHARE CqShaderVM : public CqShaderStack, public IqShader, p
 		CqShaderVM&	operator=( const CqShaderVM& From );
 
 	private:
+		/** \brief Load a compiled shader program from the given stream
+		 *
+		 * \throw XqBadShader If the program was compiled with a different
+		 *   version of aqsis, or is invalid in any other way.
+		 */
+		void	LoadProgram( std::istream* pFile );
+		void	Execute( IqShaderExecEnv* pEnv );
+		void	ExecuteInit();
+
+		// Allow createShaderVM to call LoadProgram:
+		friend boost::shared_ptr<IqShader> createShaderVM(
+				IqRenderer* renderContext, std::istream& programFile,
+				const std::string& dsoPath);
 
 		struct SqArgumentRecord
 		{
@@ -232,6 +236,7 @@ class AQSIS_SHADERVM_SHARE CqShaderVM : public CqShaderStack, public IqShader, p
 		IqTransformPtr m_pTransform;    ///< Pointer to the transformation at the time the shader was instantiated.
 
 		std::vector<IqShaderData*>	m_LocalVars;		///< Array of local variables.
+		std::vector<IqShaderData*>	m_InstancedParams;	///< Array of (instance parameter,local var) pairs.  Includes default params.
 		std::vector<SqArgumentRecord>	m_StoredArguments;		///< Array of arguments specified during construction.
 		std::vector<UsProgramElement>	m_ProgramInit;		///< Bytecodes of the intialisation program.
 		std::vector<UsProgramElement>	m_Program;			///< Bytecodes of the main program.
@@ -305,11 +310,11 @@ class AQSIS_SHADERVM_SHARE CqShaderVM : public CqShaderStack, public IqShader, p
 			TqUlong hash = CqString::hash(strName);
 
 			for ( ; m_LocalIndex < m_LocalVars.size(); m_LocalIndex++ )
-				if ( CqString::hash(m_LocalVars[ m_LocalIndex ] ->strName().c_str()) == hash )
+				if ( m_LocalVars[ m_LocalIndex ] ->strNameHash() == hash )
 					return ( m_LocalIndex );
 
 			for ( m_LocalIndex = 0; m_LocalIndex < tmp; m_LocalIndex++ )
-				if ( CqString::hash(m_LocalVars[ m_LocalIndex ] ->strName().c_str()) == hash )
+				if ( m_LocalVars[ m_LocalIndex ] ->strNameHash() == hash )
 					return ( m_LocalIndex );
 			return ( -1 );
 		}
@@ -322,7 +327,7 @@ class AQSIS_SHADERVM_SHARE CqShaderVM : public CqShaderStack, public IqShader, p
 			TqUlong hash = CqString::hash(strName);
 
 			for ( TqUint m = 0; m < m_LocalVars.size(); m++ )
-				if ( CqString::hash(m_LocalVars[ m ] ->strName().c_str()) == hash )
+				if ( m_LocalVars[ m ] ->strNameHash() == hash )
 					return ( m );
 			return ( -1 );
 		}
@@ -683,6 +688,7 @@ class AQSIS_SHADERVM_SHARE CqShaderVM : public CqShaderStack, public IqShader, p
 		void	SO_external();
 		void	SO_occlusion();
 		void	SO_occlusion_rt();
+		void	SO_indirectdiffuse();
 		void	SO_rayinfo();
 		void	SO_bake3d();
 		void	SO_texture3d();
